# Hardware-Aware Optimization and Design Automation

Reusable Python utilities for hardware-aware optimization and design automation.

## Feature Synopsis

+ [ ] intermediate representation (IR) system
+ [ ] Xilinx tool backend
+ [ ] Xilinx report parser
+ [ ] Intel tool backend
+ [ ] Intel report parser

## Getting Started

### Prerequisites

+ Python 3.5+ and corresponding `pip`

<details><summary>How to install Python 3.5+ on Ubuntu 16.04+ and CentOS 7?</summary>

#### Ubuntu 16.04+

```bash
sudo apt install python3 python3-pip
```

#### CentOS 7

```bash
sudo yum install python3 python3-pip
```

</details>

### Installing from PyPI

```bash
python3 -m pip install --user --upgrade haoda
```

### Installing from Source

```bash
python3 setup.py install --user
```

### Installing for Development

```bash
python3 -m pip install --editable .
```
